## CSS - Demos - Badges

<script type="module" src="/web_components/js/css/demos/WebC__CSS__Demo__Badges.mjs"></script>

<webc-container>
    <webc-css-demo-badges        ></webc-css-demo-badges> 
    <webc-css-demo-badges no-css ></webc-css-demo-badges>
    
</webc-container>